# ModelId


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from haplohub.models.model_id import ModelId

# TODO update the JSON string below
json = "{}"
# create an instance of ModelId from a JSON string
model_id_instance = ModelId.from_json(json)
# print the JSON string representation of the object
print ModelId.to_json()

# convert the object into a dict
model_id_dict = model_id_instance.to_dict()
# create an instance of ModelId from a dict
model_id_from_dict = ModelId.from_dict(model_id_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


